@@ -129,55 +129,8 @@ sub build_root_directory {
 ####################
 
 # For use in BUILD
-sub _name_never_ends_with_slash { $_[0]->{name} =~ s|/\s*$|| }
-
-# For helping build root_directory for some VCSes
-sub _directory_from_list {
-    my ($self, $root_directory, $dir_names, $file_names, $strip_root) = @_;
-    
-    # Sorting assures that parent directories will always be in the array
-    # before child directories.
-    my @dir_array = sort {length($a) <=> length($b)} @$dir_names;
-    my $root_path = $root_directory->path->stringify;
-    my %dirs = ("$root_path" => $root_directory);
-    my %dir_contents;
-    
-    # Create objects for the Directories and set their parents appropriately.
-    foreach my $path (@dir_array) {
-        ($path =~ s/^\Q$strip_root\E//) if defined $strip_root;
-        next if !$path;
-        my $path_obj    = Path::Abstract->new($path)->to_branch;
-        my $parent_name = $path_obj->parent->stringify;
-        my $parent      = $dirs{$parent_name};
-        
-        my $directory = $self->repository->vci->directory_class->new(
-            path => $path_obj, parent => $parent, project => $self);
-        $dirs{$path_obj->stringify} = $directory;
-        
-        $dir_contents{$parent_name} ||= [];
-        push(@{ $dir_contents{$parent_name} }, $directory);
-    }
-
-    # Create File objects and set their parent directories correctly.
-    foreach my $path (@$file_names) {
-        ($path =~ s/^\Q$strip_root\E//) if defined $strip_root;
-        my $path_obj    = Path::Abstract->new($path)->to_branch;
-        my $parent_name = $path_obj->parent->stringify;
-        my $parent      = $parent_name ? $dirs{$parent_name} : $root_directory;
-        
-        my $file = $self->repository->vci->file_class->new(
-            parent => $parent, path => $path_obj, project => $self);
-        
-        $dir_contents{$parent_name} ||= [];
-        push(@{ $dir_contents{$parent_name} }, $file);
-    }
-    
-    foreach my $dir (keys %dir_contents) {
-        $dirs{$dir}->{contents} = $dir_contents{$dir};
-    }
-    
-    return $root_directory;
-}
+sub _name_never_ends_with_slash   { $_[0]->{name} =~ s|/+\s*$|| }
+sub _name_never_starts_with_slash { $_[0]->{name} =~ s|^\s*/+|| }
 
 __PACKAGE__->meta->make_immutable;
 
