@@ -10,7 +10,7 @@ extends 'VCI::Abstract::Commit';
 
 sub x_from_log {
     my ($class, $project, $paths, $revno, $who, $when, $message) = @_;
-    my %copied;
+    my (%copied, %moved);
     my %actions = ('A' => [], 'D' => [], 'M' => []);
     
     my $project_path = $project->name;
@@ -22,22 +22,20 @@ sub x_from_log {
         # because Path::Abstract was a major performance bottleneck in tests
         # here.
         my $path = $name;
-        $path =~ s|^/?\Q$project_path\E/?||;
+        # We don't track changes to other Projects.
+        ($path =~ s|^/\Q$project_path\E/||) || next;
         
         my $from_path = $item->copyfrom_path;
         if ($from_path) {
-            my $from_parent = Path::Abstract->new($from_path);
-            my $from_longer = scalar($from_parent->list)
-                              - scalar($project_path =~ tr|/||);
-            my $from_file   = $from_parent->pop($from_longer);
-            
-            # $from_parent is now just the "project" part of the path. Let's
-            # normalize it for comparison purposes.
-            $from_parent = $from_parent->to_branch;
-            
             # We were either copied from this project or a different one.
-            my $project_from = $project;
-            if ($from_parent->stringify ne $project_path) {
+            my ($project_from, $from_file);
+
+            my $orig_from_path = $from_path;
+            if ($from_path =~ s|^/\Q$project_path\E/||) {
+                $from_file = Path::Abstract->new($from_path);
+                $project_from = $project;
+            }
+            else {
                 # We just use the very first directory as the name of the
                 # project we copied from. There's no way to know what part
                 # of the path represents the branch.
@@ -47,10 +45,27 @@ sub x_from_log {
                     $project->repository->get_project(name => $proj_from_name);
                 $from_file = Path::Abstract->new(($full_path->list)[1..-1]);
             }
-            my $copied_from = VCI::VCS::Svn::FileOrDirectory->new(
-                path => $from_file, project => $project_from,
-                revision => $item->copyfrom_rev);
-            $copied{$path} = $copied_from;
+            
+            # XXX We don't currently track moves, because we can't reliably
+            #     tell if the file was modified or not!
+            # If the copyfrom_path was deleted in this rev, then this is
+            # a move.
+            #if (exists $paths->{$orig_from_path}
+            #    && $paths->{$orig_from_path}->action eq 'D')
+            #{
+            #    $moved{$path} = $from_file->stringify;
+                # Don't tag it as deleted, just as moved.
+            #    delete $paths->{$orig_from_path};
+            #    $actions{'D'} = [grep { $_ ne $from_file->stringify }
+            #                          @{$actions{'D'}}];
+            #}
+            # Otherwise it's a copy.
+            #else {
+                my $copied_from = VCI::VCS::Svn::FileOrDirectory->new(
+                    path => $from_file, project => $project_from,
+                    revision => $item->copyfrom_rev);
+                $copied{$path} = $copied_from;
+            #}
         }
         
         my $obj = VCI::VCS::Svn::FileOrDirectory->new(
@@ -58,16 +73,14 @@ sub x_from_log {
             revision => $revno, time => $when);
         my $action = $paths->{$name}->action;
         if ($action eq 'R') {
-            push(@{ $actions{'A'} }, $obj);
-            # XXX Perhaps this should actually contain the removed revision?
-            #     That's tricky, though.
-            push(@{ $actions{'D'} }, $obj);
+            push(@{ $actions{'M'} }, $obj);
         }
         else {
             push(@{$actions{$action}}, $obj);
         }
     }
-    
+        
+    chomp($message);
     return $class->new(
         revision  => $revno,
         time      => $when,
@@ -76,6 +89,7 @@ sub x_from_log {
         added     => $actions{'A'},
         removed   => $actions{'D'},
         modified  => $actions{'M'},
+        #moved     => \%moved,
         copied    => \%copied,
         project   => $project,
     );
@@ -90,7 +104,6 @@ sub build_as_diff {
     # Diff doesn't work unless these have filenames, for some reason.
     my ($out, $oname) = tempfile();
     my ($err, $ename) = tempfile();
-    warn "Path: [$path] Prev: [$previous_rev] Cur: [$rev]";
     $ctx->diff([], $path, $previous_rev, $path, $rev, 1, 0, 0, $oname, $ename);
     { local $/ = undef; $err = <$err>; $out = <$out> }
     confess($err) if $err;
